using C1.Win.TreeView;

namespace WinFormsTestTree
{
    public partial class Form1 : Form
    {
        private Font useFont = new Font("Tahoma", 12, FontStyle.Regular);

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.Cursor = Cursors.AppStarting;

            label1.Font = useFont;
            label2.Font = useFont;
            label3.Font = useFont;
            lblParent.Font = useFont;
            lblParent.Text = "";
            lblText.Font = useFont;
            lblText.Text = "";
            textBox1.Font = useFont;
            button1.Font = useFont;

            TreeView_AddNodes();

            this.Cursor = Cursors.Default;
        }

        private void TreeView_AddNodes()
        {
            #region TreeView styles

            tree1.CheckBoxes = false;
            tree1.BackColor = Color.Linen;
            tree1.ForeColor = Color.Black;
            tree1.BorderStyle = BorderStyle.FixedSingle;
            tree1.BorderColor = Color.Red;
            tree1.Styles.ShowLines = true;
            tree1.Styles.LinesWidth = 2;
            tree1.Styles.LinesColor = Color.IndianRed;
            tree1.Styles.Font = useFont;
            tree1.Styles.LinesStyle = System.Drawing.Drawing2D.DashStyle.Solid;
            tree1.Styles.BorderColor = Color.Blue;
            tree1.Styles.BorderStyle = C1TreeViewBorderStyle.ColumnsHeaderOnly;

            tree1.ShowColumnHeaders = true;
            tree1.Columns.Clear();
            tree1.Nodes.Clear();

            #endregion

            #region TreeView columns

            C1TreeColumn column0 = new C1TreeColumn();
            column0.Name = "Column0";
            column0.DisplayFieldName = "Text"; //Set DisplayFieldName to the property of your DataModel class
            column0.HeaderText = "Text";
            column0.Width = 500;
            column0.Styles.ColumnHeader.Font = useFont;
            column0.Styles.ColumnHeader.BackColor = Color.Gold;
            column0.Styles.ColumnHeader.ForeColor = Color.Black;
            tree1.Columns.Add(column0);

            C1TreeColumn column1 = new C1TreeColumn();
            column1.Name = "Column1";
            column1.DisplayFieldName = "Number"; //Set DisplayFieldName to the property of your DataModel class
            column1.HeaderText = "Number";
            column1.Width = 100;
            column1.Styles.ColumnHeader.Font = useFont;
            column1.Styles.ColumnHeader.BackColor = Color.Gold;
            column1.Styles.ColumnHeader.ForeColor = Color.Black;
            tree1.Columns.Add(column1);

            #endregion

            #region Add Nodes

            tree1.BeginUpdate();

            for (int i = 0; i < 3; i++)
            {
                string key = "Parent " + i.ToString();

                C1TreeNode parent = new C1TreeNode();                       
                tree1.Nodes.Add(parent);

                /*To set Data in a node
                (1) create your DataModel object, and
                (2) set it to node using SetValue method (Each col will show value as per DisplayFieldName)
                 */
                var parentVal = new NodeDataModel(key, string.Empty); 
                parent.SetValue(parentVal);

                if (i == 0)
                {
                    C1TreeNode child1 = new C1TreeNode();                   
                    parent.Nodes.Add(child1);                               
                    var val = new NodeDataModel("First choice for first parent", "4"); 
                    child1.SetValue(val);                                

                    C1TreeNode child2 = new C1TreeNode();
                    parent.Nodes.Add(child2);
                    val = new NodeDataModel("Second choice for first parent", "8");
                    child2.SetValue(val);

                    C1TreeNode child3 = new C1TreeNode();
                    parent.Nodes.Add(child3);
                    val = new NodeDataModel("Third choice for first parent", "2");
                    child3.SetValue(val);
                }
                else if (i == 1)
                {
                    C1TreeNode child1 = new C1TreeNode();
                    parent.Nodes.Add(child1);
                    var val = new NodeDataModel("First choice for second parent", "11");
                    child1.SetValue(val);

                    C1TreeNode child2 = new C1TreeNode();
                    parent.Nodes.Add(child2);
                    val = new NodeDataModel("Second choice for second parent", "6");
                    child2.SetValue(val);

                    C1TreeNode child3 = new C1TreeNode();
                    parent.Nodes.Add(child3);
                    val = new NodeDataModel("Third choice for second parent", "14");
                    child3.SetValue(val);
                }
                else if (i == 2)
                {
                    C1TreeNode child1 = new C1TreeNode();
                    parent.Nodes.Add(child1);
                    var val = new NodeDataModel("First choice for third parent", "29");
                    child1.SetValue(val);

                    C1TreeNode child2 = new C1TreeNode();
                    parent.Nodes.Add(child2);
                    val = new NodeDataModel("Second choice for third parent", "8");
                    child2.SetValue(val);

                    C1TreeNode child3 = new C1TreeNode();
                    parent.Nodes.Add(child3);
                    val = new NodeDataModel("Third choice for third parent", "2");
                    child3.SetValue(val);

                    C1TreeNode child4 = new C1TreeNode();
                    parent.Nodes.Add(child4);
                    val = new NodeDataModel("Fourth choice for third parent", "15");
                    child4.SetValue(val);
                }
            }
            tree1.EndUpdate();

            #endregion
        }

        #region tv_ApplyNodeStyles
        private void tv_ApplyNodeStyles(object sender, C1TreeViewNodeStylesEventArgs e)
        {
            if (e.Node.Level == 0)
            {
                //Niv 0
                e.NodeStyles.Font = useFont;
                e.NodeStyles.Default.BackColor = Color.PeachPuff;       //Show text
                e.NodeStyles.Default.ForeColor = Color.IndianRed;
                e.NodeStyles.Hot.BackColor = Color.Yellow;              //Mouse over text
                e.NodeStyles.Hot.ForeColor = Color.Blue;
                e.NodeStyles.HotSelected.BackColor = Color.Linen;       //Click on row
                e.NodeStyles.HotSelected.ForeColor = Color.IndianRed;
            }
            else if (e.Node.Level == 1)
            {
                e.NodeStyles.Font = useFont;
                e.NodeStyles.Default.BackColor = Color.Beige;
                e.NodeStyles.Default.ForeColor = Color.BlueViolet;
                e.NodeStyles.Hot.BackColor = Color.LightBlue;
                e.NodeStyles.Hot.ForeColor = Color.Black;
                e.NodeStyles.HotSelected.BackColor = Color.PeachPuff;
                e.NodeStyles.HotSelected.ForeColor = Color.IndianRed;
            }
        }
        #endregion

        private void tree1_SelectionChanged(object sender, C1TreeViewEventArgs e)
        {
            if (tree1.SelectedNodes.Length > 0)
            {
                if (tree1.SelectedNodes[0].Level == 1)
                {
                    //Selected child
                    string select1 = tree1.SelectedNodes[0].ParentCollection.Parent.GetValue(0).ToString();
                    string select2 = tree1.SelectedNodes[0].GetValue(0).ToString();
                    string select3 = tree1.SelectedNodes[0].GetValue(1).ToString();

                    lblParent.Text = select1;
                    lblText.Text = select2;
                    textBox1.Text = select3;
                }
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            //check if valid number
            if (int.TryParse(textBox1.Text, out int _))
            {
                tree1.SelectedNodes[0].SetValue(textBox1.Text, 1);
                MessageBox.Show("Number Updated");
            }
            else
            {
                MessageBox.Show("Enter Valid Number");
            }
        }
    }
}
